==> owncloud-client_2.11.0.8354+dfsg.orig.tar.xz: ownCloud-2.11.0.8354/README.md <==
# ownCloud Desktop Client

[![Build Status](https://drone.owncloud.com/api/badges/owncloud/client/status.svg)](https://drone.owncloud.com/owncloud/client) [![Build Status](https://github.com/owncloud/client/workflows/ownCloud%20CI/badge.svg)](https://github.com/owncloud/client/actions)


## Introduction

The ownCloud Desktop Client is a tool to synchronize files from ownCloud Server
with your computer.

## Download

### Binary packages

* Refer to the download page https://owncloud.org/download/#owncloud-desktop-client

### Source code

The ownCloud Desktop Client is developed in Git. Since Git makes it easy to
fork and improve the source code and to adapt it to your need, many copies
can be found on the Internet, in particular on GitHub. However, the
authoritative repository maintained by the developers is located at
https://github.com/owncloud/client.

## Building the source code

[Building the Client](https://doc.owncloud.org/desktop/building.html)
in the ownCloud Desktop Client manual.

## Reporting issues and contributing

If you find any bugs or have any suggestion for improvement, please
file an issue at https://github.com/owncloud/client/issues. Do not
contact the authors directly by mail, as this increases the chance
of your report being lost.

If you created a patch, please submit a [Pull
Request](https://github.com/owncloud/client/pulls). For non-trivial
patches, we need you to sign the [Contributor
Agreement](https://owncloud.com/contribute/join-the-development/contributor-agreement/) before
we can accept your patch.

If you want to contact us, e.g. before starting a more complex feature,
you can join us at
[RocketChat](https://talk.owncloud.com/channel/desktop).

## Maintainers and Contributors

The current maintainers of this repository are:

* Hannah von Reth <hannah.vonreth@owncloud.com>
* Dominik Schmidt <dev@dominik-schmidt.de>

ownCloud Desktop Client is developed by the ownCloud community and [receives
patches from a variety of authors](https://github.com/owncloud/client/graphs/contributors).

Past maintainers:

* Markus Goetz <guruz@owncloud.com>
* Olivier Goffart <ogoffart@owncloud.com>
* Christian Kamm <mail@ckamm.de>
* Thomas Müller <thomas.mueller@owncloud.com>
* Klaas Freitag <freitag@owncloud.com>
* Daniel Molkentin <daniel@molkentin.de>
* Andreas Schneider <asn@cryptomilk.org>

## License

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
    or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
    for more details.

==> owncloud-client_5.2.1.13040+dfsg.orig.tar.xz: ownCloud-5.2.1.13040/README.md <==
# ownCloud Desktop Client

[![Build Status](https://drone.owncloud.com/api/badges/owncloud/client/status.svg)](https://drone.owncloud.com/owncloud/client) [![Build Status](https://github.com/owncloud/client/workflows/ownCloud%20CI/badge.svg)](https://github.com/owncloud/client/actions)


## Introduction

The ownCloud Desktop Client is a tool to synchronize files from ownCloud Server
with your computer.

## Download

### Binary packages

* Refer to the download page https://owncloud.com/desktop-app/

### Source code

The ownCloud Desktop Client is developed in Git. Since Git makes it easy to
fork and improve the source code and to adapt it to your need, many copies
can be found on the Internet, in particular on GitHub. However, the
authoritative repository maintained by the developers is located at
https://github.com/owncloud/client.

## Building the source code

[Building the Client](https://doc.owncloud.com/desktop/next/appendices/building.html)
in the ownCloud Desktop Client manual.

## Reporting issues and contributing

If you find any bugs or have any suggestion for improvement, please
file an issue at https://github.com/owncloud/client/issues. Do not
contact the authors directly by mail, as this increases the chance
of your report being lost.

If you created a patch, please submit a [Pull
Request](https://github.com/owncloud/client/pulls). For non-trivial
patches, we need you to sign the [Contributor
Agreement](https://owncloud.com/contribute/join-the-development/contributor-agreement/) before
we can accept your patch.

If you want to contact us, e.g. before starting a more complex feature,
you can join us at
[RocketChat](https://talk.owncloud.com/channel/desktop).

## Maintainers and Contributors

The current maintainers of this repository are:

* Hannah von Reth <hannah.vonreth@owncloud.com>
* Fabian Müller <fmueller@owncloud.com>
* Dominik Schmidt <dev@dominik-schmidt.de>

ownCloud Desktop Client is developed by the ownCloud community and [receives
patches from a variety of authors](https://github.com/owncloud/client/graphs/contributors).

Past maintainers:

* Markus Goetz <guruz@owncloud.com>
* Olivier Goffart <ogoffart@owncloud.com>
* Christian Kamm <mail@ckamm.de>
* Thomas Müller <thomas.mueller@owncloud.com>
* Klaas Freitag <freitag@owncloud.com>
* Daniel Molkentin <daniel@molkentin.de>
* Andreas Schneider <asn@cryptomilk.org>

## License

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
    or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
    for more details.
